﻿using System;
using System.Collections.Generic;
using System.Drawing.Printing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using MigraDoc.DocumentObjectModel;
using MigraDoc.DocumentObjectModel.IO;
using MigraDoc.Rendering;
using MigraDoc.Rendering.Printing;

namespace PrintDemo_gdi
{
    class Program
    {
        static void Main(string[] args)
        {

            PrinterSettings printerSettings = new PrinterSettings();

            using (PrintDialog dialog = new PrintDialog())
            {
                dialog.PrinterSettings = printerSettings;
                dialog.AllowSelection = true;
                dialog.AllowSomePages = true;
                var result = dialog.ShowDialog();

                if (result == DialogResult.OK)
                {
                    PrintDemo(printerSettings);
                }
            }
        }

        private static void PrintDemo(PrinterSettings printerSettings)
        {
            var document = MakeDemoDocument();

#if WPF
            // MigraDocPrintDocument uses the GDI build of PDFsharp/MigraDoc.
            // The Document class known to MigraDocPrintDocument is not the Document class we use here (it is from the WPF build).
            // To bridge the gap, we have to use MigraDocPrintDocumentEx and pass an MDDDL string.
            MigraDocPrintDocumentEx printDocument = new MigraDocPrintDocumentEx(DdlWriter.WriteToString(document));
#else
            // Creates a PrintDocument that simplyfies printing of MigraDoc documents
            // Code that uses the GDI build of PDFsharp/MigraDoc can use the MigraDocPrintDocument class and pass the object of Document class directly.
            // Using an MDDDL will work with all builds, but will lose a few nanoseconds.
            MigraDocPrintDocument printDocument = new MigraDocPrintDocument(document);
#endif

            // Attach the current printer settings
            printDocument.PrinterSettings = printerSettings;

            if (printerSettings.PrintRange == PrintRange.Selection)
                throw new NotImplementedException();

            // Print the document
            printDocument.Print();
        }

        private static Document MakeDemoDocument()
        {
            // Create a new MigraDoc document
            Document document = new Document();

            // Add a section to the document
            Section section = document.AddSection();

            // Add a paragraph to the section
            Paragraph paragraph = section.AddParagraph();

            paragraph.Format.Font.Color = Color.FromCmyk(100, 30, 20, 50);

            // Add some text to the paragraph
            paragraph.AddFormattedText("Hello, World!", TextFormat.Bold);

            return document;
        }
    }
}
